aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio/Tango.PMR/Integration/ExternalClientLoginRequest.cs
diff options
context:
space:
mode:
authorRoy <roy.mail.net@gmail.com>2017-12-26 21:16:15 +0200
committerRoy <roy.mail.net@gmail.com>2017-12-26 21:16:15 +0200
commit2ea2bb5bcd96045f1bd6cb4c3d8b8416dbaa05dc (patch)
treea21ff27fff08876e835df82c5242def1f0d09c17 /Software/Visual_Studio/Tango.PMR/Integration/ExternalClientLoginRequest.cs
parent6450fc175114a6f8d0b75cb21386d1bb0c902711 (diff)
downloadTango-2ea2bb5bcd96045f1bd6cb4c3d8b8416dbaa05dc.tar.gz
Tango-2ea2bb5bcd96045f1bd6cb4c3d8b8416dbaa05dc.zip
MERGE
Diffstat (limited to 'Software/Visual_Studio/Tango.PMR/Integration/ExternalClientLoginRequest.cs')
-rw-r--r--Software/Visual_Studio/Tango.PMR/Integration/ExternalClientLoginRequest.cs40
1 files changed, 20 insertions, 20 deletions
diff --git a/Software/Visual_Studio/Tango.PMR/Integration/ExternalClientLoginRequest.cs b/Software/Visual_Studio/Tango.PMR/Integration/ExternalClientLoginRequest.cs
index 2b614b2ed..a3a1295d5 100644
--- a/Software/Visual_Studio/Tango.PMR/Integration/ExternalClientLoginRequest.cs
+++ b/Software/Visual_Studio/Tango.PMR/Integration/ExternalClientLoginRequest.cs
@@ -23,13 +23,13 @@ namespace Tango.PMR.Integration {
byte[] descriptorData = global::System.Convert.FromBase64String(
string.Concat(
"CiBFeHRlcm5hbENsaWVudExvZ2luUmVxdWVzdC5wcm90bxIVVGFuZ28uUE1S",
- "LkludGVncmF0aW9uIikKGkV4dGVybmFsQ2xpZW50TG9naW5SZXF1ZXN0EgsK",
- "A2tleRgBIAEoCUIhCh9jb20udHdpbmUudGFuZ28ucG1yLmludGVncmF0aW9u",
- "YgZwcm90bzM="));
+ "LkludGVncmF0aW9uIi4KGkV4dGVybmFsQ2xpZW50TG9naW5SZXF1ZXN0EhAK",
+ "CFBhc3N3b3JkGAEgASgJQiEKH2NvbS50d2luZS50YW5nby5wbXIuaW50ZWdy",
+ "YXRpb25iBnByb3RvMw=="));
descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
new pbr::FileDescriptor[] { },
new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
- new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Integration.ExternalClientLoginRequest), global::Tango.PMR.Integration.ExternalClientLoginRequest.Parser, new[]{ "Key" }, null, null, null)
+ new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Integration.ExternalClientLoginRequest), global::Tango.PMR.Integration.ExternalClientLoginRequest.Parser, new[]{ "Password" }, null, null, null)
}));
}
#endregion
@@ -60,7 +60,7 @@ namespace Tango.PMR.Integration {
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public ExternalClientLoginRequest(ExternalClientLoginRequest other) : this() {
- key_ = other.key_;
+ password_ = other.password_;
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
@@ -68,14 +68,14 @@ namespace Tango.PMR.Integration {
return new ExternalClientLoginRequest(this);
}
- /// <summary>Field number for the "key" field.</summary>
- public const int KeyFieldNumber = 1;
- private string key_ = "";
+ /// <summary>Field number for the "Password" field.</summary>
+ public const int PasswordFieldNumber = 1;
+ private string password_ = "";
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public string Key {
- get { return key_; }
+ public string Password {
+ get { return password_; }
set {
- key_ = pb::ProtoPreconditions.CheckNotNull(value, "value");
+ password_ = pb::ProtoPreconditions.CheckNotNull(value, "value");
}
}
@@ -92,14 +92,14 @@ namespace Tango.PMR.Integration {
if (ReferenceEquals(other, this)) {
return true;
}
- if (Key != other.Key) return false;
+ if (Password != other.Password) return false;
return true;
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public override int GetHashCode() {
int hash = 1;
- if (Key.Length != 0) hash ^= Key.GetHashCode();
+ if (Password.Length != 0) hash ^= Password.GetHashCode();
return hash;
}
@@ -110,17 +110,17 @@ namespace Tango.PMR.Integration {
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public void WriteTo(pb::CodedOutputStream output) {
- if (Key.Length != 0) {
+ if (Password.Length != 0) {
output.WriteRawTag(10);
- output.WriteString(Key);
+ output.WriteString(Password);
}
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public int CalculateSize() {
int size = 0;
- if (Key.Length != 0) {
- size += 1 + pb::CodedOutputStream.ComputeStringSize(Key);
+ if (Password.Length != 0) {
+ size += 1 + pb::CodedOutputStream.ComputeStringSize(Password);
}
return size;
}
@@ -130,8 +130,8 @@ namespace Tango.PMR.Integration {
if (other == null) {
return;
}
- if (other.Key.Length != 0) {
- Key = other.Key;
+ if (other.Password.Length != 0) {
+ Password = other.Password;
}
}
@@ -144,7 +144,7 @@ namespace Tango.PMR.Integration {
input.SkipLastField();
break;
case 10: {
- Key = input.ReadString();
+ Password = input.ReadString();
break;
}
}